# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RelayService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import type_pb2 as google_dot_protobuf_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12RelayService.proto\x12\x19nP.grpc.relayServiceProto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x1agoogle/protobuf/type.proto\"|\n\x08ShortMsg\x12/\n\x0bmsgSentTime\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x05topic\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.EnumValue\x12\x14\n\x0c\x65rrorMessage\x18\x04 \x01(\t\"g\n\x07\x46ullMsg\x12\x35\n\x08metadata\x18\x01 \x01(\x0b\x32#.nP.grpc.relayServiceProto.ShortMsg\x12%\n\x07message\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any2\xc8\x01\n\x0cRelayService\x12]\n\x0eGetTopicStream\x12#.nP.grpc.relayServiceProto.ShortMsg\x1a\".nP.grpc.relayServiceProto.FullMsg\"\x00\x30\x01\x12Y\n\x0cPublishTopic\x12\".nP.grpc.relayServiceProto.FullMsg\x1a#.nP.grpc.relayServiceProto.ShortMsg\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RelayService_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SHORTMSG._serialized_start=137
  _SHORTMSG._serialized_end=261
  _FULLMSG._serialized_start=263
  _FULLMSG._serialized_end=366
  _RELAYSERVICE._serialized_start=369
  _RELAYSERVICE._serialized_end=569
# @@protoc_insertion_point(module_scope)
